@@ -9,31 +9,35 @@ package App::Pastebin::Create;
 
 =pod
 
-=endcoding UTF-8
+=encoding UTF-8
 
 =head1 NAME
+
 App::Pastebin::Create - CLI to create Pastebin.com paste and uploading.
 
 Adapted from WWW::Pastebin::PastebinCom::Create module.
 
 
 =head1 VERSION
-version 1.000
+
+version 1.0002
 
 =head1 EXAMPLE USAGE
-	pastebin-create --text 'TEXT' --format 'none' --expiry 10m --private 0 --desc 'A TITLE'
+		pastebin-create --text 'TEXT' --format 'none' --expiry 10m --private 0 --desc 'A TITLE'
 
 =head1 OPTIONS
 
 =head2 --text, -t
-REQUIRED: This flag required to run the program (at minimum).
+REQUIRED
+
+This flag required to run the program (at minimum).
 
 Functioning as your paste text flag (STDIN from file, will be implemented).
 
 =head2 --format, -f
 OPTIONAL
 
-Syntax highlighting choice, see here for list - https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create
+Syntax highlighting choice, see here for list - L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>
 
 =head2 --expiry, -e
 OPTIONAL
@@ -58,9 +62,8 @@ mfzz, <mfzz@cpan.org>
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by mfzz.
- 
- This is free software; you can redistribute it and/or modify it under
- the same terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
